@@ -1,6 +1,7 @@
+set.seed(20240110)
 test_that("gen_centroids() works", {
 
-  all_centroids_df <- gen_centroids(nldr_obj = scurve_model_obj$nldr_obj,
+  all_centroids_df <- gen_centroids(nldr_scaled_obj = scurve_model_obj$nldr_scaled_obj,
                                     b1 = 4, q = 0.1)
 
   testthat::expect_snapshot(all_centroids_df)
@@ -20,7 +21,7 @@ test_that("gen_hex_coord() works", {
 test_that("assign_data() works", {
 
   all_centroids_df <- scurve_model_obj$hb_obj$centroids
-  umap_with_hb_id <- assign_data(nldr_obj = scurve_model_obj$nldr_obj,
+  umap_with_hb_id <- assign_data(nldr_scaled_obj = scurve_model_obj$nldr_scaled_obj,
                                  centroids_data = all_centroids_df)
 
   testthat::expect_snapshot(umap_with_hb_id)
@@ -36,48 +37,48 @@ test_that("compute_std_counts() works", {
 
 })
 
-test_that("find_pts() works", {
+test_that("group_hex_pts() works", {
 
   umap_with_hb_id <- scurve_model_obj$hb_obj$data_hb_id
 
-  testthat::expect_snapshot(find_pts(scaled_nldr_hexid = umap_with_hb_id))
+  testthat::expect_snapshot(group_hex_pts(scaled_nldr_hexid = umap_with_hb_id))
 
 })
 
 test_that("hex_binning() works", {
 
-  testthat::expect_snapshot(hex_binning(nldr_obj = scurve_model_obj$nldr_obj,
+  testthat::expect_snapshot(hex_binning(nldr_scaled_obj = scurve_model_obj$nldr_scaled_obj,
                                         b1 = 4, q = 0.1))
 
 })
 
 test_that("find_non_empty_bins() works", {
 
-  testthat::expect_snapshot(find_non_empty_bins(nldr_obj = scurve_model_obj$nldr_obj,
+  testthat::expect_snapshot(find_non_empty_bins(nldr_scaled_obj = scurve_model_obj$nldr_scaled_obj,
                                                 m = 5))
 
-  testthat::expect_error(find_non_empty_bins(nldr_obj = scurve_model_obj$nldr_obj,
+  testthat::expect_error(find_non_empty_bins(nldr_scaled_obj = scurve_model_obj$nldr_scaled_obj,
                                              m = 21))
 
 })
 
-test_that("extract_hexbin_centroids() works", {
+test_that("merge_hexbin_centroids() works", {
 
   all_centroids_df <- scurve_model_obj$hb_obj$centroids
   counts_data <- scurve_model_obj$hb_obj$std_cts
 
-  testthat::expect_snapshot(extract_hexbin_centroids(centroids_data = all_centroids_df,
+  testthat::expect_snapshot(merge_hexbin_centroids(centroids_data = all_centroids_df,
                                                      counts_data = counts_data))
 
 })
 
-test_that("extract_hexbin_mean() works", {
+test_that("merge_hexbin_mean() works", {
 
   all_centroids_df <- scurve_model_obj$hb_obj$centroids
   counts_data <- scurve_model_obj$hb_obj$std_cts
   umap_with_hb_id <- scurve_model_obj$hb_obj$data_hb_id
 
-  testthat::expect_snapshot(extract_hexbin_mean(data_hb = umap_with_hb_id,
+  testthat::expect_snapshot(merge_hexbin_mean(data_hb = umap_with_hb_id,
                                                 counts_data = counts_data,
                                                 centroids_data = all_centroids_df))
 
@@ -88,7 +89,7 @@ test_that("tri_bin_centroids() works", {
   all_centroids_df <- scurve_model_obj$hb_obj$centroids
   counts_data <- scurve_model_obj$hb_obj$std_cts
   umap_with_hb_id <- scurve_model_obj$hb_obj$data_hb_id
-  df_bin_centroids <- extract_hexbin_mean(data_hb = umap_with_hb_id,
+  df_bin_centroids <- merge_hexbin_mean(data_hb = umap_with_hb_id,
   counts_data = counts_data, centroids_data = all_centroids_df)
 
   testthat::expect_snapshot(suppressWarnings(tri_bin_centroids(centroids_data = df_bin_centroids)))
@@ -108,7 +109,7 @@ test_that("gen_edges() works", {
   all_centroids_df <- scurve_model_obj$hb_obj$centroids
   counts_data <- scurve_model_obj$hb_obj$std_cts
   umap_with_hb_id <- scurve_model_obj$hb_obj$data_hb_id
-  df_bin_centroids <- extract_hexbin_centroids(counts_data = counts_data,
+  df_bin_centroids <- merge_hexbin_centroids(counts_data = counts_data,
                                                centroids_data = all_centroids_df)
   suppressWarnings(tr1_object <- tri_bin_centroids(centroids_data = df_bin_centroids))
 
