@@ -14,9 +14,11 @@ test_that("show_link_plots() works", {
   if(interactive()) {
 
     df_exe <- comb_all_data_model(highd_data = scurve, nldr_data = scurve_umap,
-                                  model_highd = scurve_model_obj$model_highd, model_2d = scurve_model_obj$model_2d)
+                                  model_highd = scurve_model_obj$model_highd,
+                                  model_2d = scurve_model_obj$model_2d)
     edge_data <- scurve_model_obj$trimesh_data
-    crosstalk_obj <- show_link_plots(point_data = df_exe, edge_data = edge_data)
+    crosstalk_obj <- suppressWarnings(show_link_plots(point_data = df_exe,
+                                                      edge_data = edge_data))
 
     testthat::expect_s3_class(crosstalk_obj, "shiny.tag")
 
@@ -45,10 +47,12 @@ test_that("show_link_plots() works", {
 
     model_error <- augment(x = scurve_model_obj, highd_data = scurve)
     df_exe <- comb_all_data_model_error(highd_data = scurve, nldr_data = scurve_umap,
-                                        model_highd = scurve_model_obj$model_highd, model_2d = scurve_model_obj$model_2d,
+                                        model_highd = scurve_model_obj$model_highd,
+                                        model_2d = scurve_model_obj$model_2d,
                                         error_data = model_error)
     edge_data <- scurve_model_obj$trimesh_data
-    crosstalk_obj <- show_error_link_plots(point_data = df_exe, edge_data = edge_data)
+    crosstalk_obj <- suppressWarnings(show_error_link_plots(point_data = df_exe,
+                                                            edge_data = edge_data))
 
     testthat::expect_s3_class(crosstalk_obj, "shiny.tag")
 
